@@ -29,6 +29,9 @@ FAILEDOPERATION_AGENTPAYDEALCANNOTDOWN = 'FailedOperation.AgentPayDealCannotDown
 # 账户余额不足。
 FAILEDOPERATION_BALANCEINSUFFICIENT = 'FailedOperation.BalanceInsufficient'
 
+# appId不符。
+FAILEDOPERATION_INVALIDAPPID = 'FailedOperation.InvalidAppId'
+
 # 订单状态错误，只有未支付订单才能支付。
 FAILEDOPERATION_INVALIDDEAL = 'FailedOperation.InvalidDeal'
 
@@ -47,6 +50,9 @@ FAILEDOPERATION_PAYPRICEERROR = 'FailedOperation.PayPriceError'
 # 支付成功但发货失败，请联系腾讯云工作人员处理。
 FAILEDOPERATION_PAYSUCCDELIVERFAILED = 'FailedOperation.PaySuccDeliverFailed'
 
+# 获取数据条数失败。
+FAILEDOPERATION_QUERYCOUNTFAILED = 'FailedOperation.QueryCountFailed'
+
 # 汇总数据正在构建中，请稍后再试。
 FAILEDOPERATION_SUMMARYDATANOTREADY = 'FailedOperation.SummaryDataNotReady'
 
